agentle.agents.whatsapp.models.whatsapp\_audio\_message
=======================================================

.. automodule:: agentle.agents.whatsapp.models.whatsapp_audio_message

   
   .. rubric:: Classes

   .. autosummary::
   
      WhatsAppAudioMessage
      WhatsAppMediaMessage
      WhatsAppMessageType
   